@@ -22,7 +22,7 @@ copyright = '2020, Jarry Shaw'
 author = 'Jarry Shaw'
 
 # The full version, including alpha/beta/rc tags
-release = '0.1.7'
+release = '0.2.1'
 
 
 # -- General configuration ---------------------------------------------------
@@ -31,10 +31,19 @@ release = '0.1.7'
 # extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
 # ones.
 extensions = [
+    'sphinx.ext.viewcode',
+    'sphinx.ext.intersphinx',
     'sphinx.ext.autodoc', 'sphinx.ext.autodoc.typehints',
     'sphinxcontrib.napoleon'
 ]
 
+intersphinx_mapping = {
+    'python': ('https://docs.python.org/3', None),
+    'requests': ('https://requests.readthedocs.io/en/latest/', None),
+    'selenium': ('https://www.selenium.dev/selenium/docs/api/py/', None),
+    'stem': ('https://stem.torproject.org/', None),
+}
+
 autodoc_typehints = 'description'
 # autodoc_member_order = 'bysource'
 autodoc_member_order = 'alphabetic'
